# Re-export from cross_web for backwards compatibility
from cross_web.request._base import (
    AsyncHTTPRequestAdapter,
    FormData,
    HTTPMethod,
    QueryParams,
    SyncHTTPRequestAdapter,
)

__all__ = [
    "AsyncHTTPRequestAdapter",
    "FormData",
    "HTTPMethod",
    "QueryParams",
    "SyncHTTPRequestAdapter",
]



# Re-export from cross_web for backwards compatibility
from cross_web.request._flask import AsyncFlaskHTTPRequestAdapter, FlaskHTTPRequestAdapter

__all__ = ["AsyncFlaskHTTPRequestAdapter", "FlaskHTTPRequestAdapter"]



# Re-export from cross_web for backwards compatibility
from cross_web.request._django import AsyncDjangoHTTPRequestAdapter, DjangoHTTPRequestAdapter

__all__ = ["AsyncDjangoHTTPRequestAdapter", "DjangoHTTPRequestAdapter"]



# Re-export from cross_web for backwards compatibility
from cross_web.request._sanic import SanicHTTPRequestAdapter, convert_request_to_files_dict

__all__ = ["SanicHTTPRequestAdapter", "convert_request_to_files_dict"]



# This package has been renamed to cross-web.
# This module re-exports all symbols from cross_web for backwards compatibility.

import warnings

warnings.warn(
    "The 'lia' package has been renamed to 'cross_web'. "
    "Please update your imports from 'from lia import ...' to 'from cross_web import ...'. "
    "The 'lia' package will be removed in a future version.",
    DeprecationWarning,
    stacklevel=2,
)

from cross_web import (
    AiohttpHTTPRequestAdapter,
    AsyncDjangoHTTPRequestAdapter,
    AsyncFlaskHTTPRequestAdapter,
    AsyncHTTPRequest,
    AsyncHTTPRequestAdapter,
    BaseRequestProtocol,
    ChaliceHTTPRequestAdapter,
    Cookie,
    DjangoHTTPRequestAdapter,
    FlaskHTTPRequestAdapter,
    FormData,
    HTTPException,
    LitestarRequestAdapter,
    QuartHTTPRequestAdapter,
    Response,
    SanicHTTPRequestAdapter,
    StarletteRequestAdapter,
    SyncHTTPRequestAdapter,
    TestingRequestAdapter,
)

__all__ = [
    "AiohttpHTTPRequestAdapter",
    "AsyncDjangoHTTPRequestAdapter",
    "AsyncFlaskHTTPRequestAdapter",
    "AsyncHTTPRequest",
    "AsyncHTTPRequestAdapter",
    "BaseRequestProtocol",
    "ChaliceHTTPRequestAdapter",
    "Cookie",
    "DjangoHTTPRequestAdapter",
    "FlaskHTTPRequestAdapter",
    "FormData",
    "HTTPException",
    "LitestarRequestAdapter",
    "QuartHTTPRequestAdapter",
    "Response",
    "SanicHTTPRequestAdapter",
    "StarletteRequestAdapter",
    "SyncHTTPRequestAdapter",
    "TestingRequestAdapter",
]
